@@ -29,7 +29,7 @@ licenceEn="""
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-import platform
+import platform, os
 
 if platform.system()=="Linux":
     userShareDir="~/.scolasync"
@@ -41,3 +41,25 @@ elif platform.system()=="Windows":
     logFileName="??"
     markFileName="??"
     
+def firstdir(l):
+    """
+    Renvoie le premier répertoire existant d'une liste de propositions
+    @param l la liste de propositions
+    """
+    for d in l:
+        if os.path.isdir(d): return d
+    return None
+   
+def _dir(which):
+    """
+    Renvoie le répertoire où trouver telle ou telle ressource
+    @param which le type de ressource
+    """
+    if which=="lang":
+        return firstdir(["/usr/share/scolasync/lang", "lang"])
+    elif which=="help":
+        return firstdir(["/usr/share/scolasync/help", "help"])
+    elif which=="share":
+        return firstdir(["/usr/share/scolasync/","share"])
+    return None
+
