@@ -26,6 +26,8 @@ licence['en']="""
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 import version
+from globaldef import _dir
+from xml.dom.minidom import parse
 
 class helpWindow(QDialog):
     def __init__(self, parent=None):
@@ -37,8 +39,9 @@ class helpWindow(QDialog):
         self.ui=Ui_Aide()
         self.ui.setupUi(self)
         self.ui.labelVersion.setText(QApplication.translate("Main","Version numéro %1.%2",None, QApplication.UnicodeUTF8).arg(version.major(), version.minor()))
+        self.loadBrowsers(_dir("help"),self.parent().locale)
         QObject.connect(self.ui.closeButton, SIGNAL("clicked()"), self.close)
-        
+
     def loadBrowsers(self, dir, locale):
         """
         met en place les textes dans les afficheurs, en fonction de la locale.
@@ -50,3 +53,12 @@ class helpWindow(QDialog):
         self.ui.authorsBrowser.setHtml(QUrl("file://"+dir+"/authors_"+locale+".html"))
         self.ui.licenseBrowser.setHtml(QUrl("file://"+dir+"/license_"+locale+".html"))
         self.ui.languagesBrowser.setHtml(QUrl("file://"+dir+"/languages_"+locale+".html"))
+        # parses the manual-tab's text to include the custom
+        # manual's URL.
+        manuals=parse(dir+"/manual_"+locale+".html")
+        dl=manuals.documentElement.getElementsByTagName("dl")[0]
+        dd=dl.getElementsByTagName("dd")[1]
+        a=dd.getElementsByTagName("a")[0]
+        a.setAttribute("href", self.parent().manFileLocation)
+        # then sets the manual-tab's contents
+        self.ui.manualBrowser.setText(manuals.toxml())
