@@ -81,7 +81,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_chooseInSticks.py" line="169"/>
+        <location filename="../Ui_copyToDialog1.py" line="198"/>
         <source>...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -121,37 +121,37 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="243"/>
+        <location filename="../mainWindow.py" line="280"/>
         <source>Double-clic non pris en compte</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="243"/>
+        <location filename="../mainWindow.py" line="280"/>
         <source>pas d&apos;action pour l&apos;attribut %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="415"/>
+        <location filename="../mainWindow.py" line="477"/>
         <source>Veuillez choisir au moins un fichier</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="411"/>
+        <location filename="../mainWindow.py" line="473"/>
         <source>Choix de la destination ...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="454"/>
+        <location filename="../mainWindow.py" line="516"/>
         <source>Voir les copies</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="462"/>
+        <location filename="../mainWindow.py" line="524"/>
         <source>Destination manquante</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="462"/>
+        <location filename="../mainWindow.py" line="524"/>
         <source>Veuillez choisir une destination pour la copie des fichiers</source>
         <translation type="unfinished"></translation>
     </message>
@@ -166,17 +166,17 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_preferences.py" line="112"/>
+        <location filename="../Ui_preferences.py" line="119"/>
         <source>Preferences de ScolaSync</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_preferences.py" line="113"/>
+        <location filename="../Ui_preferences.py" line="120"/>
         <source>Preferences</source>
         <translation>Préférences</translation>
     </message>
     <message>
-        <location filename="../Ui_preferences.py" line="121"/>
+        <location filename="../Ui_preferences.py" line="128"/>
         <source>Travail</source>
         <translation type="unfinished"></translation>
     </message>
@@ -191,22 +191,22 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ownedUsbDisk.py" line="161"/>
+        <location filename="../ownedUsbDisk.py" line="170"/>
         <source>inconnu</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ownedUsbDisk.py" line="203"/>
+        <location filename="../ownedUsbDisk.py" line="212"/>
         <source>La cle %1&lt;br&gt;n&apos;est pas identifiee, donnez le nom du proprietaire</source>
         <translation>La clé %1&lt;br&gt;n&apos;est pas identifiée, donnez le nom du propriétaire</translation>
     </message>
     <message>
-        <location filename="../ownedUsbDisk.py" line="204"/>
+        <location filename="../ownedUsbDisk.py" line="213"/>
         <source>Entrer un nom</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainWindow.py" line="360"/>
+        <location filename="../mainWindow.py" line="422"/>
         <source>Vous allez effacer plusieurs baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
@@ -261,17 +261,17 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_preferences.py" line="115"/>
+        <location filename="../Ui_preferences.py" line="122"/>
         <source>Les cases à cocher permettent de n&apos;agir que sur une part des baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_preferences.py" line="116"/>
+        <location filename="../Ui_preferences.py" line="123"/>
         <source>Utiliser des cases à cocher pour désigner les baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_preferences.py" line="120"/>
+        <location filename="../Ui_preferences.py" line="127"/>
         <source>Répertoire pour les travaux :</source>
         <translation type="unfinished"></translation>
     </message>
@@ -296,32 +296,32 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="353"/>
+        <location filename="../mainWindow.py" line="415"/>
         <source>Choix de fichiers à supprimer (jokers autorisés)</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="415"/>
+        <location filename="../mainWindow.py" line="477"/>
         <source>Aucun fichier sélectionné</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="409"/>
+        <location filename="../mainWindow.py" line="471"/>
         <source>Choix de fichiers à copier</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="410"/>
+        <location filename="../mainWindow.py" line="472"/>
         <source>Choix de fichiers à copier depuis les baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="423"/>
+        <location filename="../mainWindow.py" line="485"/>
         <source>Choisir un répertoire de destination</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="454"/>
+        <location filename="../mainWindow.py" line="516"/>
         <source>Voulez-vous voir les fichiers copiés ?</source>
         <translation type="unfinished"></translation>
     </message>
@@ -331,27 +331,27 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_preferences.py" line="122"/>
+        <location filename="../Ui_preferences.py" line="129"/>
         <source>Fichier spécial pour le manuel :</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_preferences.py" line="123"/>
+        <location filename="../Ui_preferences.py" line="130"/>
         <source>/usr/share/scolasync/help/manualPage_fr_FR.html</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_preferences.py" line="124"/>
+        <location filename="../Ui_preferences.py" line="131"/>
         <source>Recomptage automatique des médias :</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_preferences.py" line="125"/>
+        <location filename="../Ui_preferences.py" line="132"/>
         <source>toutes les</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_preferences.py" line="126"/>
+        <location filename="../Ui_preferences.py" line="133"/>
         <source>30 secondes</source>
         <translation type="unfinished"></translation>
     </message>
@@ -371,30 +371,210 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="486"/>
+        <location filename="../mainWindow.py" line="547"/>
         <source>Réitérer la dernière commande</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="486"/>
+        <location filename="../mainWindow.py" line="547"/>
         <source>La dernière commande était&lt;br&gt;%1&lt;br&gt;Voulez-vous la relancer avec les nouveaux baladeurs ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_preferences.py" line="119"/>
+        <location filename="../Ui_preferences.py" line="126"/>
         <source>Efface les fichiers et les répertoires après copie</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_preferences.py" line="117"/>
+        <location filename="../Ui_preferences.py" line="124"/>
         <source>Si la case est cochée,&lt;br&gt;les données sont transférées sur le disque dur&lt;br&gt;puis effacée des baladeurs.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_preferences.py" line="118"/>
+        <location filename="../Ui_preferences.py" line="125"/>
         <source>Si la case est cochée, les données sont transférées sur le disque dur puis effacée des baladeurs.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="117"/>
+        <source>Choix d&apos;un groupe d&apos;élèves</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_choixEleves.py" line="120"/>
+        <source>Actions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_choixEleves.py" line="121"/>
+        <source>Replier toutes les classes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_choixEleves.py" line="122"/>
+        <source>Tout replier</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="123"/>
+        <source>Cocher tous les élèves visibles</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_choixEleves.py" line="124"/>
+        <source>Cocher</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="125"/>
+        <source>Décocher tous les élèves, visibles ou non</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="126"/>
+        <source>Décocher</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="128"/>
+        <source>Ajout à la liste</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_choixEleves.py" line="130"/>
+        <source>Suppr. de la liste</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_choixEleves.py" line="135"/>
+        <source>Valider</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="132"/>
+        <source>N° à partir de</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="131"/>
+        <source>Quand la case est cochée, un numéro sera ajouté comme préfixe aux noms</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="133"/>
+        <source>La numérotation commence à cette valeur</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="127"/>
+        <source>Ajouter les noms cochés de l&apos;arbre dans la liste à droite</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_choixEleves.py" line="129"/>
+        <source>Supprimer de la liste les noms en surbrillance</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_choixEleves.py" line="134"/>
+        <source>Accepter la liste actuelle et fermer ce dialogue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_choixEleves.py" line="136"/>
+        <source>Supprimer tous les noms de la liste et fermer ce dialogue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="137"/>
+        <source>Remettre à zéro</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../ownedUsbDisk.py" line="70"/>
+        <source>Choix du propriétaire</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../ownedUsbDisk.py" line="71"/>
+        <source>Nouveau nom du propriétaire du baladeur</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_choixEleves.py" line="118"/>
+        <source>Liste d&apos;élèves</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_choixEleves.py" line="119"/>
+        <source>Ouvrir un fichier ...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_preferences.py" line="134"/>
+        <source>Fichier des élèves :</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_nameAdrive.py" line="72"/>
+        <source>Nommer le baladeur nouvellement connecté</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_nameAdrive.py" line="73"/>
+        <source>Changez le choix parmi cette liste si une autre ligne convient mieux</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_nameAdrive.py" line="75"/>
+        <source>nom actuel du baladeur</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_nameAdrive.py" line="76"/>
+        <source>C&apos;est le nom connu par votre ordinateur, s&apos;il a déjà été défini dans le passé</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_nameAdrive.py" line="77"/>
+        <source>nom proposé</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_nameAdrive.py" line="78"/>
+        <source>Le nouveau nom proposé peut venir de la liste à gauche ou être modifié à la main</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_nameAdrive.py" line="79"/>
+        <source>Renommer le baladeur</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_nameAdrive.py" line="80"/>
+        <source>Choisir comme nouveau nom</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../Ui_nameAdrive.py" line="81"/>
+        <source>Fermer le dialogue sans rien faire</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../Ui_nameAdrive.py" line="82"/>
+        <source>Échappement</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../choixEleves.py" line="94"/>
+        <source>Échec à l&apos;ouverture du fichier élèves</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../choixEleves.py" line="94"/>
+        <source>Le fichier %1 n&apos;a pas pu être traité</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context encoding="UTF-8">
     <name>Main</name>
@@ -404,47 +584,47 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="514"/>
+        <location filename="../mainWindow.py" line="581"/>
         <source>Démontage des baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="514"/>
+        <location filename="../mainWindow.py" line="581"/>
         <source>Êtes-vous sûr de vouloir démonter tous les baladeurs cochés de la liste ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="734"/>
+        <location filename="../mainWindow.py" line="801"/>
         <source>Propriétaire de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour modifier.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="736"/>
+        <location filename="../mainWindow.py" line="803"/>
         <source>Point de montage de la clé USB ou du baladeur ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir les fichiers.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="738"/>
+        <location filename="../mainWindow.py" line="805"/>
         <source>Capacité de la clé USB ou du baladeur en kO ;&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour voir la place occupée.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="740"/>
+        <location filename="../mainWindow.py" line="807"/>
         <source>Fabricant de la clé USB ou du baladeur.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="742"/>
+        <location filename="../mainWindow.py" line="809"/>
         <source>Modèle de la clé USB ou du baladeur.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="744"/>
+        <location filename="../mainWindow.py" line="811"/>
         <source>Numéro de série de la clé USB ou du baladeur.</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="732"/>
+        <location filename="../mainWindow.py" line="799"/>
         <source>Cocher ou décocher cette case en cliquant.&lt;br&gt;&lt;b&gt;Double-clic&lt;/b&gt; pour agir sur plusieurs baladeurs.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -472,12 +652,12 @@ p, li { white-space: pre-wrap; }
         <translation>Utilisé(s)</translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="133"/>
+        <location filename="../Ui_mainWindow.py" line="149"/>
         <source>ScolaSync</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="134"/>
+        <location filename="../Ui_mainWindow.py" line="150"/>
         <source>Actions</source>
         <translation type="unfinished"></translation>
     </message>
@@ -502,65 +682,75 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">Préférences</translation>
     </message>
     <message>
-        <location filename="../Ui_mainWindow.py" line="159"/>
+        <location filename="../Ui_mainWindow.py" line="176"/>
         <source>Aide</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_mainWindow.py" line="153"/>
+        <location filename="../Ui_mainWindow.py" line="170"/>
         <source>Force à recompter les baladeurs</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_mainWindow.py" line="151"/>
+        <location filename="../Ui_mainWindow.py" line="168"/>
         <source>Affiche le nombre de baladeurs connectés</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_mainWindow.py" line="156"/>
+        <location filename="../Ui_mainWindow.py" line="173"/>
         <source>Préférences</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_mainWindow.py" line="147"/>
+        <location filename="../mainWindow.py" line="201"/>
         <source>Refaire à nouveau</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_mainWindow.py" line="148"/>
+        <location filename="../mainWindow.py" line="202"/>
         <source>Refaire à nouveau la dernière opération réussie, avec les baladeurs connectés plus récemment</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_mainWindow.py" line="145"/>
+        <location filename="../Ui_mainWindow.py" line="161"/>
         <source>Éjecter les baladeurs sélectionnés</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_mainWindow.py" line="136"/>
+        <location filename="../Ui_mainWindow.py" line="152"/>
         <source>Copier depuis les baladeurs sélectionnés</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_mainWindow.py" line="139"/>
+        <location filename="../Ui_mainWindow.py" line="155"/>
         <source>Copier vers les baladeurs sélectionnés</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../Ui_mainWindow.py" line="142"/>
+        <location filename="../Ui_mainWindow.py" line="158"/>
         <source>Effacer des fichiers ou des dossiers dans les baladeurs sélectionnés</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="167"/>
+        <location filename="../mainWindow.py" line="203"/>
         <source>Arrêter les opérations en cours</source>
         <translation type="unfinished"></translation>
     </message>
     <message encoding="UTF-8">
-        <location filename="../mainWindow.py" line="168"/>
+        <location filename="../mainWindow.py" line="204"/>
         <source>Essaie d&apos;arrêter les opérations en cours. À faire seulement si celles-ci durent trop longtemps</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../mainWindow.py" line="77"/>
+        <source>&lt;br /&gt;Des noms sont disponibles pour renommer les prochains baladeurs que vous brancherez</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message encoding="UTF-8">
+        <location filename="../mainWindow.py" line="78"/>
+        <source>&lt;br /&gt;Cliquez sur ce bouton pour préparer une liste de noms afin de renommer les prochains baladeurs que vous brancherez</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>checkBoxDialog</name>
@@ -641,7 +831,7 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ownedUsbDisk.py" line="145"/>
+        <location filename="../ownedUsbDisk.py" line="154"/>
         <source>owner</source>
         <translation>propriétaire</translation>
     </message>
