@@ -31,6 +31,8 @@ import os.path, operator, subprocess, dbus, re, time, copy
 from notification import Notification
 import db
 import deviceListener
+import choixEleves
+import nameAdrive
 from globaldef import logFileName, _dir
 
 # cette donnée est globale, pour être utilisé depuis n'importe quel objet
@@ -69,6 +71,13 @@ class mainWindow(QMainWindow):
         from Ui_mainWindow  import Ui_MainWindow
         self.ui = Ui_MainWindow()
         self.ui.setupUi(self)
+        # crée le dialogue des nouveaux noms
+        self.namesFullIcon=QIcon("/usr/share/icons/Tango/scalable/actions/gtk-find-and-replace.svg")
+        self.namesEmptyIcon=QIcon("/usr/share/icons/Tango/scalable/actions/gtk-find.svg")
+        self.namesFullTip=QApplication.translate("MainWindow", "<br />Des noms sont disponibles pour renommer les prochains baladeurs que vous brancherez", None, QApplication.UnicodeUTF8)
+        self.namesEmptyTip=QApplication.translate("MainWindow", "<br />Cliquez sur ce bouton pour préparer une liste de noms afin de renommer les prochains baladeurs que vous brancherez", None, QApplication.UnicodeUTF8)
+        self.namesDialog=choixEleves.choixElevesDialog(parent =self)
+        self.recentConnect="" # chemin dbus pour un baladeur récemment connecté
         # initialise deux icônes
         self.initRedoStuff()
         # initialise le tableau
@@ -80,6 +89,8 @@ class mainWindow(QMainWindow):
         self.applyPreferences()
         self.listener=deviceListener.DeviceListener(self)
         self.updateButtons()
+        self.availableNames=False # cette variable est regénérée ci-dessous
+        self.setAvailableNames(False)
         self.operations=[] # liste des opérations précédemment "réussies"
         self.oldThreads=set() # threads lancés éventuellement encore vivants
         self.flashTimer=QTimer()
@@ -94,6 +105,7 @@ class mainWindow(QMainWindow):
         QObject.connect(self.ui.fromButton, SIGNAL("clicked()"), self.copyFrom)
         QObject.connect(self.ui.delButton, SIGNAL("clicked()"), self.delFiles)
         QObject.connect(self.ui.redoButton, SIGNAL("clicked()"), self.redoCmd)
+        QObject.connect(self.ui.namesButton, SIGNAL("clicked()"), self.namesCmd)
         QObject.connect(self.ui.preferenceButton, SIGNAL("clicked()"), self.preference)
         QObject.connect(self.ui.tableView, SIGNAL("doubleClicked(const QModelIndex&)"), self.tableClicked)
         QObject.connect(self,SIGNAL("deviceAdded(QString)"), self.deviceAdded)
@@ -101,7 +113,8 @@ class mainWindow(QMainWindow):
         QObject.connect(self,SIGNAL("checkAll()"), self.checkAll)
         QObject.connect(self,SIGNAL("checkToggle()"), self.checkToggle)
         QObject.connect(self,SIGNAL("checkNone()"), self.checkNone)
-
+        QObject.connect(self,SIGNAL("shouldNameDrive()"), self.namingADrive)
+        
     def checkModify(self, boolFunc):
         """
         @param boolfunc une fonction pour décider du futur état de la coche
@@ -133,16 +146,39 @@ class mainWindow(QMainWindow):
         Décoche tous les baladeurs
         """
         self.checkModify(lambda x: False)
-        
+
+    def namingADrive(self):
+        """
+        Gère un dialogue pour renommer un baladeur désigné par
+        self.recentConnect
+        """
+        if self.availableNames:
+            stickId, tattoo, uuid = self.listener.identify(self.recentConnect)
+            hint=db.readStudent(stickId, uuid, tattoo)
+            if hint != None:
+                oldName=hint
+            else:
+                oldName=""
+            d=nameAdrive.nameAdriveDialog(self, oldName=oldName,
+                                          nameList=self.namesDialog.itemStrings(),
+                                          driveIdent=(stickId, uuid, tattoo))
+            d.show()
+            result=d.exec_()
+        return
+    
     def deviceAdded(self, s):
         """
         fonction de rappel pour un medium ajouté
         @param s chemin UDisks, exemple : /org/freedesktop/UDisks/devices/sdb3
         """
-        ## print "dans deviceAdded", s
-        if self.listener.vfatUsbPath(str(s)):
-            self.checkDisks(noLoop=True)
-        
+        vfatPath = self.listener.vfatUsbPath(str(s))
+        if vfatPath:
+            self.recentConnect=str(s)
+            # pas tout à fait équivalent à l'émission d'un signal avec emit :
+            # le timer s'exécutera en dehors du thread qui appartient à DBUS !
+            QTimer.singleShot(0, self.namingADrive)
+        self.checkDisks(noLoop=True)
+            
     def deviceRemoved(self, s):
         """
         fonction de rappel pour un medium retiré
@@ -192,6 +228,7 @@ class mainWindow(QMainWindow):
         Applique les préférences et les options de ligne de commande
         """
         prefs=db.readPrefs()
+        self.schoolFile=prefs["schoolFile"]
         self.workdir=prefs["workdir"]
         self.refreshEnabled=prefs["refreshEnabled"]
         self.refreshDelay=prefs["refreshDelay"]
@@ -295,11 +332,29 @@ class mainWindow(QMainWindow):
         @param idx un QModelIndex qui pointe sur le propriétaire d'une clé
         """
         student=u"%s" %self.tm.data(idx,Qt.DisplayRole).toString()
-        ownedUsbDisk.editRecord(self.diskFromOwner(student), prompt=student)
+        ownedUsbDisk.editRecord(self.diskFromOwner(student), hint=student)
         other=ownedUsbDisk.Available(self.checkable,access="firstFat")
         qApp.diskData=other
         self.connectTableModel(other)
         self.checkDisks()
+
+    def setAvailableNames(self, available):
+        """
+        Met à jour l'icône qui reflète la disponibilité de noms pour
+        renommer automatiquement des baladeurs
+        @param available vrai s'il y a des noms disponibles pour
+        renommer des baladeurs.
+        """
+        self.availableNames=available
+        if available:
+            icon=self.namesFullIcon
+            msg=self.namesFullTip
+        else:
+            icon=self.namesEmptyIcon
+            msg=self.namesEmptyTip
+        self.ui.namesButton.setIcon(icon)
+        self.ui.namesButton.setToolTip(msg)
+        self.ui.namesButton.setStatusTip(msg.remove("<br />"))
         
     def updateButtons(self):
         """
@@ -308,6 +363,8 @@ class mainWindow(QMainWindow):
         une opération de copie avant même de brancher des clés, donc on les
         active. Par contre démonter les clés quand elles sont absentes ça
         n'a pas d'utilité.
+        Change l'icône du dialogue des noms selon qu'il reste ou non des
+        noms disponibles dans le dialogue des noms.
         """
         global activeThreads, lastCommand
         active = len(qApp.diskData)>0
@@ -331,6 +388,11 @@ class mainWindow(QMainWindow):
             self.ui.redoButton.setToolTip(self.redoToolTip)
             self.ui.redoButton.setStatusTip(self.redoStatusTip)
             self.ui.redoButton.setEnabled(lastCommand!=None)
+        l=self.namesDialog.ui.listWidget.findItems("*",Qt.MatchWildcard)
+        if len(l)>0:
+            self.ui.namesButton.setIcon(self.namesFullIcon)
+        else:
+            self.ui.namesButton.setIcon(self.namesEmptyIcon)
 
     def preference(self):
         """
@@ -472,7 +534,6 @@ class mainWindow(QMainWindow):
         """
         global lastCommand, pastCommands, activeThreads
         if len(activeThreads)>0:
-            print "GRRRR il faut stopper des threads", self.oldThreads
             for thread in self.oldThreads:
                 if thread.isAlive():
                     try:
@@ -495,7 +556,13 @@ class mainWindow(QMainWindow):
                 t.start()
                 self.oldThreads.add(t)
                 pastCommands[lastCommand].append(p.owner)
-        
+
+    def namesCmd(self):
+        """
+        montre le dialogue de choix de nouveaux noms à partir d'un
+        fichier administratif.
+        """
+        self.namesDialog.show()
 
     def help(self):
         """
@@ -563,7 +630,7 @@ class mainWindow(QMainWindow):
         self.proxy.setSourceModel(self.t.model())
 
         
-    def checkDisks(self, force=False, noLoop=False):
+    def checkDisks(self, force=False, noLoop=True):
         """
         fonction relancée périodiquement pour vérifier s'il y a un changement
         dans le baladeurs, et signaler dans le tableau les threads en cours.
