@@ -34,17 +34,42 @@ liste statique pour éviter de demander chaque seconde le nom d'un
 propriétaire de clé si on n'a pas souhaité le donner.
 """
 
-def editRecord(owd, prompt=""):
+def tattooInDir(mountPoint):
+    """
+    Renvoie le tatouage pour un point de montage donné, quitte à le créer
+    si nécessaire.
+    @param mountPoint un point de montage de partition
+    @return le tatouage
+    """
+    tattooFileName = os.path.join(mountPoint,".scolasync-tattoo")
+    tattoo_=""
+    if os.path.exists(tattooFileName):
+        tattoo_=open(tattooFileName,"r").readlines()[0].strip()
+    if tattoo_ != "" :
+        # le tatouage existe déjà, on renvoie sa valeur
+        return tattoo_
+    else:
+        tattoo_="%12.2f" %time.time()
+        time.sleep(0.05)
+        # si on espace deux créations de tatouages de 50 millisecondes
+        # il est impossible d'avoir deux tatouages identiques générés
+        # par le même ordinateur. Les chances que ça arrive avec des
+        # ordinateurs distincts sont minimes
+        outfile=open(tattooFileName,"w")
+        outfile.write(tattoo_)
+        outfile.close()
+        # on renvoie le nouveau tatouage
+        return tattoo_
+
+def editRecord(owd, hint=""):
     """
     édition de la base de données
     @param owd une instance de ownedUsbDisk
-    @param prompt chaîne vide par défaut. Peut être le nom de l'ancien propriétaire
+    @param hint chaîne vide par défaut. Peut être le nom de l'ancien propriétaire
     """
-    newStudent, ok = QInputDialog.getText(None,
-                                          u"Choix du propriétaire",
-                                          u"Nouveau nom du propriétaire de la clé",
-                                          text=prompt
-                                          )
+    title=QApplication.translate("Dialog", "Choix du propriétaire", None, QApplication.UnicodeUTF8)
+    prompt=QApplication.translate("Dialog", "Nouveau nom du propriétaire du baladeur", None, QApplication.UnicodeUTF8)
+    newStudent, ok = QInputDialog.getText(None, title, prompt, text=hint)
     if ok:
         newStudent=u"%s" %newStudent
         db.writeStudent(owd.stickid, owd.getFatUuid(), owd.tattoo(), newStudent)
@@ -83,23 +108,7 @@ class uDisk(usbDisk.uDisk,QObject):
         ff=self.getFirstFat()
         if ff:
             fatPath=ff.ensureMounted()
-            tattooFileName=os.path.join(fatPath,".scolasync-tattoo")
-            if os.path.exists(tattooFileName):
-                tattoo_=open(tattooFileName,"r").read()
-                # on vérifie par acquis de conscience, qu'il n'existe pas
-                # un tatouage identique dans la base de données
-                # s'il est déjà présent : on le change. Il faudrait
-                # probablement aussi prévenir le prof !!!
-                if tattoo_ in db.tattooList():
-                    tattoo_="%12.2f" %time.time()
-                    time.sleep(0.05)
-            else:
-                tattoo_="%12.2f" %time.time()
-                time.sleep(0.05)
-                outfile=open(tattooFileName,"w")
-                outfile.write(tattoo_)
-                outfile.close()
-            return tattoo_
+            return tattooInDir(fatPath)
         else:
             return ""
     
@@ -215,7 +224,7 @@ class Available(usbDisk.Available):
     avant le montage des partions FAT.
     """
 
-    def __init__(self, checkable=False, access="disk", diskClass=uDisk, diskDict=None, noLoop=False):
+    def __init__(self, checkable=False, access="disk", diskClass=uDisk, diskDict=None, noLoop=True):
         """
         Le constructeur est un proxy pour usbDisk.Available.__init__
         qui force la classe de disques à utiliser : en effet ici
