@@ -62,6 +62,7 @@ class preferenceWindow(QDialog):
         prefs={}
         prefs["checkable"]      = bool(self.ui.checkCheck.isChecked())
         prefs["mv"]             = bool(self.ui.mvCheck.isChecked())
+        prefs["schoolFile"]     = "%s" %self.ui.lineEditSchoolFile.text().toUtf8()
         prefs["workdir"]        = "%s" %self.ui.dirEdit.text().toUtf8()
         prefs["manfile"]        = "%s" %self.ui.manFileEdit.text().toUtf8()
         prefs["refreshEnabled"] = bool(self.ui.refreshEnabledBox.isChecked())
@@ -89,6 +90,7 @@ class preferenceWindow(QDialog):
             state=Qt.Unchecked
         self.ui.refreshEnabledBox.setCheckState(state)
         self.ui.refreshDelaySlider.setEnabled(prefs["refreshEnabled"])
+        self.ui.lineEditSchoolFile.setText(prefs["schoolFile"])
         self.ui.dirEdit.setText(prefs["workdir"])
         self.ui.manFileEdit.setText(prefs["manfile"])
         self.ui.refreshDelaySlider.setValue(prefs["refreshDelay"])
