@@ -126,11 +126,9 @@ licenceFr="""
 licence['fr']=licenceFr
 
 
-import mainWindow
-from PyQt4.QtCore import *
+import getopt, os, sys
 from PyQt4.QtGui import *
-import sys, os, os.path, getopt, subprocess
-from globaldef import logFileName
+from PyQt4.QtCore import *
 
 def usage():
     """
@@ -145,17 +143,13 @@ Options :
 
 def run():
     """
-    C'est la fonction principale.
-
-     Elle crée un fichier de journalisation vide, puis lance
-     l'application interactive elle-même. Le fichier de journalisation
-     est ${HOME}/.scolasync/scolasync.log sous Linux
+    Le lancement de l'application
     """
+    from dbus.mainloop.qt import DBusQtMainLoop
+    DBusQtMainLoop(set_as_default=True)
     
-    subprocess.call(": > " + logFileName ,shell=True)
-        
     app = QApplication(sys.argv)
-    
+
     args=sys.argv[1:]
     try:
         #opts,args= ["check"], sys.argv
@@ -165,21 +159,22 @@ def run():
         sys.exit(2)
 
     locale = "%s" %QLocale.system().name()
-    ## qtTranslator = QTranslator()
-    ## if qtTranslator.load("qt_" + locale):
-    ##     print "OK for qttranslator"
-    ##     app.installTranslator(qtTranslator)
+    qtTranslator = QTranslator()
+    if qtTranslator.load("qt_" + locale, "/usr/share/qt4/translations"):
+        # print "OK for qttranslator"
+        app.installTranslator(qtTranslator)
     appTranslator = QTranslator()
-    langdir=os.path.join(mainWindow._dir("lang"),locale+".qm")
+    langdir=os.path.join("lang",locale+".qm")
     b= appTranslator.load(langdir)
     if b:
         # print "installation du fichier de traduction", langdir
         app.installTranslator(appTranslator)
 
-    
+    import mainWindow
     windows = mainWindow.mainWindow(None,opts,locale)
     windows.show()
+    
     sys.exit(app.exec_())
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     run()
