@@ -24,7 +24,7 @@ licence_en="""
 
 licence['en']=licence_en
 
-import dbus, subprocess, os.path, re
+import dbus, subprocess, os.path, re, time
 from PyQt4.QtGui import *
 
 
@@ -181,14 +181,15 @@ class uDisk:
     def isDosFat(self):
         """
         Permet de reconnaitre les partitions DOS-FAT
-        @return vrai dans le cas d'une partition FAT16 ou FAT32
+        @return True dans le cas d'une partition FAT16 ou FAT32
         """
-        try:
-            code=eval(self.getProp("partition-type"))
-            fatCodes = [0x04, 0x06, 0x0b, 0x0c, 0x0d, 0x0e]
-            return code in fatCodes
-        except:
-            return False
+        return self.getProp("id-type")=="vfat"
+
+    def isMounted(self):
+        """
+        @return True si le disque ou la partion est montée
+        """
+        return bool(self.getProp("device-is-mounted"))
         
     def valuableProperties(self,indent=4):
         """
@@ -211,7 +212,8 @@ class uDisk:
                "id-uuid",
                "partition-slave",
                "partition-type",
-               "device-size"]
+               "device-size",
+               "id-type"]
         for prop in props:
             p=self.getProp(prop)
             if isinstance(p,dbus.Array):
@@ -300,19 +302,31 @@ class uDisk:
         """
         if self.isDosFat(): return self
         return self.firstFat
-    
+
     def ensureMounted(self):
         """
         Permet de s'assurer qu'une partition ou un disque sera bien monté
         @result le chemin du point de montage
         """
         mount_paths=self.getProp("device-mount-paths")
-        if len(mount_paths)==0:
+        if mount_paths==None: # le cas où la notion de montage est hors-sujet
+            return ""
+        leftTries=5
+        while len(mount_paths)==0 and leftTries >0:
+            leftTries = leftTries - 1
             path=self.getProp("device-file-by-id")
-            if isinstance(path,dbus.Array):
+            if isinstance(path,dbus.Array) and len(path)>0:
                 path=path[0]
-            subprocess.call("udisks --mount %s" %path,shell=True)
-            return path
+                subprocess.call("udisks --mount %s > /dev/null" %path,shell=True)
+                paths=self.getProp("device-mount-paths")
+                if paths:
+                    return self.getProp("device-mount-paths")[0]
+                else:
+                    time.sleep(0.5)
+            else:
+                time.sleep(0.5)
+        if leftTries==0:
+            raise Exception, "Could not mount the VFAT after 5 tries." 
         else:
             return mount_paths[0]
 
@@ -333,7 +347,7 @@ class Available:
     - \b firstFats une liste composée de la première partion DOS-FAT de chaque disque USB.
     """
 
-    def __init__(self, checkable=False, access="disk"):
+    def __init__(self, checkable=False, access="disk", diskClass=uDisk, diskDict=None):
         """
         Le constructeur
         @param checkable : vrai si on veut pouvoir cocher les disques de la
@@ -341,7 +355,10 @@ class Available:
         @param access définit le type d'accès souhaité. Par défaut, c'est "disk"
           c'est à dire qu'on veut la liste des disques USB. Autres valeurs
           possibles : "firstFat" pour les premières partitions vfat.
+        @param diskClass la classe de disques à créer
+        @param diskDict un dictionnaire des disque maintenu par deviceListener
         """
+        ## print "GRRRR should use diskDict=", diskDict
         self.checkable=checkable
         self.access=access
         self.bus = dbus.SystemBus()
@@ -352,7 +369,7 @@ class Available:
         self.enumDev=iface.EnumerateDevices()
         ### récupération des disques usb dans le dictionnaire self.disks
         for path in self.enumDev:
-            ud=uDisk(path, self.bus, checkable)
+            ud=diskClass(path, self.bus, checkable)
             if ud.isUsbDisk():
                 self.disks[ud]=[]
                 # cas des disques sans partitions
@@ -362,13 +379,24 @@ class Available:
                     self.disks[ud].append(ud)
         ### une deuxième passe pour récupérer et associer les partitions
         for path in self.enumDev:
-            ud=uDisk(path, self.bus, checkable)
+            ud=diskClass(path, self.bus, checkable)
             for d in self.disks.keys():
                 if ud.master() == d.path:
                     self.disks[d].append(ud)
-        ### on fabrique la liste des premières partitions FAT
+        self.finishInit()
+
+    def finishInit(self):
+        """
+        Fin de l'initialisation
+        """
+        self.mountFirstFats()
+
+    def mountFirstFats(self):
+        """
+        fabrique la liste des partitions FAT,
+        monte les partitions FAT si elles ne le sont pas
+        """
         self.firstFats = self.getFirstFats()
-        ### on monte les partitions si nécessaire
         if self.access=="firstFat":
             for p in self.firstFats:
                 p.ensureMounted()
@@ -455,8 +483,10 @@ class Available:
 
     def getFirstFats(self, setOwners=False):
         """
-        Facilite l'accès aux partitions de type DOS-FAT, et a un effet de bord :
-        marque le disque avec l'uuid de la première partition FAT.
+        Facilite l'accès aux partitions de type DOS-FAT, et a des effets
+        de bord :
+          * marque le disque avec l'uuid de la première partition FAT.
+          * construit une liste des chemins uDisk des FATs
         @param setOwners si égale à True,
           signale que la liste devra comporter des attributs de propriétaire
           de medias.
@@ -464,6 +494,7 @@ class Available:
           partition de type FAT de chaque disque USB connecté
         """
         result=[]
+        self.fatPaths=[]
         for d in self.disks.keys():
             for p in self.disks[d]:
                 if p.isDosFat() or p==d :
@@ -471,6 +502,7 @@ class Available:
                     # on va supposer que dans ce cas la partition ne peut
                     # être que de type DOS !!!
                     result.append(p)
+                    self.fatPaths.append(p.title())
                     # on marque le disque père et la partition elle-même
                     d.fatuuid=p.uuid
                     d.firstFat=p
@@ -480,6 +512,19 @@ class Available:
                     break
         return result
 
+    def hasDev(self, dev):
+        """
+        @param dev un chemin comme /org/freedesktop/UDisks/devices/sdb3
+        @return True si la partition est dans la liste des partions disponibles
+        """
+        s="%s" %dev
+        s=s.replace("/org/freedesktop/UDisks/devices/","")
+        for p in self.fatPaths:
+            if p.split("/")[-1]==s:
+                return True
+        return False
+    
+
 if __name__=="__main__":
     machin=Available()
     print machin
