@@ -21,7 +21,7 @@ licenceEn="""
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-import subprocess, threading, re, os.path, time, glob, shlex
+import subprocess, threading, re, os, os.path, shutil, time, glob, shlex
 from PyQt4.QtCore import *
 
 _threadNumber=0
@@ -112,28 +112,6 @@ def _date():
     """
     return time.strftime("%Y/%m/%d-%H:%M:%S")
 
-def _call(cmd, logfile, ud, parent=None):
-    """
-    Lance une commande dans un shell, et journalise la réussite ou l'échec
-    @param cmd la commande shell, si cette commande contient des points-virgules elle sera découpée en plusieurs sous-commandes, chacune traitée séparément.
-    @param logfile le fichier de journalisation
-    @param ud le uDisk concerné
-    @param parent un widget qui recevra des signaux de début et de fin
-       de commande. Par defaut: None.
-    """
-    if parent:
-        parent.emit(SIGNAL("pushCmd(QString, QString)"), ud.owner, cmd)
-    for command in cmd.split(";"):
-        retcode=subprocess.call(command, shell=True)
-        msg="[%s] " %_date()
-        if retcode==0:
-            msg += "Success: "
-        else:
-            msg += "Error:   "
-        msg += command
-    if parent:
-        parent.emit(SIGNAL("popCmd(QString, QString)"), ud.owner, cmd+msg)
-
 class abstractThreadUSB(threading.Thread):
     """
     Une classe abstraite
@@ -165,6 +143,67 @@ class abstractThreadUSB(threading.Thread):
         self.logfile=logfile
         self.parent=parent
 
+    def writeToLog(self, msg):
+        """
+        Écrit un message dans le fichier de journalisation
+        @param msg le message
+        """
+        open(os.path.expanduser(self.logfile),"a").write(msg+"\n")
+        return
+
+    def copytree(self,src, dst, symlinks=False, ignore=None, erase=False, errors=[]):
+        """
+        Une version modifiée de shutil.copytree qui accepte que les
+        repertoires destination soient déjà existants. Cette source dérive
+        de la documentation fournie avec Python 2.7
+        @param src un nom de fichier ou de répertoire
+        @param dst un nom de de répertoire (déjà existant ou à créer)
+        @param symlinks vrai si on veut recopier les liens tels quels
+        @param ignore une fonction qui construit une liste de fichiers à ignorer (profil : répertoire, liste de noms de fichiers -> liste de noms de fichiers à ignorer)
+        @param erase s'il est vrai la source est effacée après copie réussie
+        @param errors la liste d'erreurs déjà relevées jusque là
+        @return une liste d'erreurs éventuellement relevées, sinon une liste vide
+        """
+        names = os.listdir(src)
+        if ignore is not None:
+            ignored_names = ignore(src, names)
+        else:
+            ignored_names = set()
+
+        try:
+            os.makedirs(dst)
+        except OSError, err:
+            pass
+        for name in names:
+            if name in ignored_names:
+                continue
+            srcname = os.path.join(src, name)
+            dstname = os.path.join(dst, name)
+            try:
+                if symlinks and os.path.islink(srcname):
+                    linkto = os.readlink(srcname)
+                    os.symlink(linkto, dstname)
+                    if not errors and erase:
+                        os.unlink(srcname)
+                elif os.path.isdir(srcname):
+                    errors=self.copytree(srcname, dstname,
+                                         symlinks=symlinks, ignore=ignore,
+                                         erase=erase, errors=errors)
+                    if not errors and erase:
+                        os.rmdir(srcname)
+                else:
+                    shutil.copy2(srcname, dstname)
+                    if not errors and erase:
+                        os.unlink(srcname)
+                # XXX What about devices, sockets etc.?
+            except (IOError, os.error), why:
+                errors.append((srcname, dstname, str(why)))
+            # catch the Error from the recursive copytree so that we can
+            # continue with other files
+            except Exception, err:
+                errors.extend(err.args[0])
+        return errors
+
     def __str__(self):
         """
         Renvoie une chaîne informative sur le thread
@@ -199,18 +238,6 @@ class abstractThreadUSB(threading.Thread):
         # ça ne fait rien du tout pour un thread abstrait
         pass
 
-    def protectPath(self, s):
-        """
-        protège une chaine unicode par des guillemets (pour un shell POSIX)
-        à moins que celle-ci contienne des jokers.
-        @param s la chaine d'entrée
-        @return la même, protégée si nécessaire
-        """
-        if "*" in s or "?" in s:
-            return s
-        else:
-            return u'"%s"' %s
-    
 class threadCopyToUSB(abstractThreadUSB):
     """
     Classe pour les threads copiant vers les clés USB
@@ -252,11 +279,31 @@ class threadCopyToUSB(abstractThreadUSB):
             subdir=subdir[1:]
         destpath=os.path.join(ud.ensureMounted(),ud.visibleDir(),subdir)
         for f in fileList:
-            fileName=os.path.basename(f)
-            cmd=self.cmd.format(fromFile=f,
-                                toDir=destpath)
-            _call(cmd, logfile, ud, self.parent)
-
+            cmd="copying %s to %s" %(f, destpath)
+            if self.parent:
+                self.parent.emit(SIGNAL("pushCmd(QString, QString)"), ud.owner, cmd)
+            destpath1=os.path.join(destpath, os.path.basename(f))
+            if os.path.isdir(f):
+                errors=self.copytree(f, destpath1)
+            else:
+                errors=[]
+                try:
+                    shutil.copy2(f, destpath1)
+                except Exceptio, err:
+                    errors.extend((f, destpath1, str(err)))
+                    
+            msg="[%s] " %_date()
+            if not errors:
+                msg += "Success: "
+            else:
+                msg += "Error:   "
+            msg += cmd
+            for e in errors:
+                msg += " <%s>" %e
+            if self.parent:
+                self.parent.emit(SIGNAL("popCmd(QString, QString)"), ud.owner, msg)
+            self.writeToLog(msg)
+            
 class threadCopyFromUSB(abstractThreadUSB):
     """
     Classe pour les threads copiant depuis les clés USB
@@ -294,15 +341,37 @@ class threadCopyFromUSB(abstractThreadUSB):
         
         for f in fileList:
             ## prend le fichier ou le répertoire sur le disque courant
-            fromPath=self.protectPath(os.path.join(ud.ensureMounted(), f))
+            fromPath=os.path.join(ud.ensureMounted(), f)
             owner=ud.ownerByDb()
             ## personnalise le nom de la destination
             newName=u"%s_%s" %(owner,os.path.dirname(f))
             ## calcule le point de copie et le répertoire à créer s'il le faut
             toPath=os.path.join(dest,newName)
-            cmd=self.cmd.format(fromPath=fromPath, toPath=toPath)
-            _call(cmd,logfile, ud, self.parent)
-            
+            cmd="copying %s to %s" %(fromPath, toPath)
+            if self.parent:
+                self.parent.emit(SIGNAL("pushCmd(QString, QString)"), ud.owner, cmd)
+            destpath1=os.path.join(toPath, os.path.basename(f))
+            if os.path.isdir(fromPath):
+                errors=self.copytree(fromPath, destpath1)
+            else:
+                errors=[]
+                try:
+                    shutil.copy2(fromPath, destpath1)
+                except Exception, err:
+                    errors.extend((fromPath, destpath1, str(err)))
+                    
+            msg="[%s] " %_date()
+            if not errors:
+                msg += "Success: "
+            else:
+                msg += "Error:   "
+            msg += cmd
+            for e in errors:
+                msg += " <%s>" %e
+            if self.parent:
+                self.parent.emit(SIGNAL("popCmd(QString, QString)"), ud.owner, msg)
+            self.writeToLog(msg)
+
 class threadMoveFromUSB(abstractThreadUSB):
     """
     Classe pour les threads déplaçant des fichiers depuis les clés USB
@@ -340,14 +409,41 @@ class threadMoveFromUSB(abstractThreadUSB):
         """
         for f in fileList:
             ## prend le fichier ou le répertoire sur le disque courant
-            fromPath=self.protectPath(os.path.join(ud.ensureMounted(), f))
+            fromPath=os.path.join(ud.ensureMounted(), f)
             owner=ud.ownerByDb()
             ## personnalise le nom de la destination
             newName=u"%s_%s" %(owner,os.path.dirname(f))
             ## calcule le point de copie et le répertoire à créer s'il le faut
             toPath=os.path.join(dest,newName)
-            cmd=self.cmd.format(fromPath=fromPath, toPath=toPath)
-            _call(cmd,logfile, ud, self.parent)
+            cmd="copying %s to %s" %(fromPath, toPath)
+            if self.parent:
+                self.parent.emit(SIGNAL("pushCmd(QString, QString)"), ud.owner, cmd)
+            destpath1=os.path.join(toPath, os.path.basename(f))
+            if os.path.isdir(fromPath):
+                errors=self.copytree(fromPath, destpath1, erase=True)
+                try:
+                    os.rmdir(fromPath)
+                except Exception, err:
+                    errors.extend((fromPath, destpath1, str(err)))
+            else:
+                errors=[]
+                try:
+                    shutil.copy2(fromPath, destpath1)
+                    os.unlink(fromPath)
+                except Exception, err:
+                    errors.extend((fromPath, destpath1, str(err)))
+                    
+            msg="[%s] " %_date()
+            if not errors:
+                msg += "Success: "
+            else:
+                msg += "Error:   "
+            msg += cmd
+            for e in errors:
+                msg += " <%s>" %e
+            if self.parent:
+                self.parent.emit(SIGNAL("popCmd(QString, QString)"), ud.owner, msg)
+            self.writeToLog(msg)
             
 class threadDeleteInUSB(abstractThreadUSB):
     """
@@ -384,5 +480,33 @@ class threadDeleteInUSB(abstractThreadUSB):
         """
         for f in fileList:
             toDel=os.path.join(ud.ensureMounted(), f)
-            cmd=self.cmd.format(toDel=toDel)
-            _call(cmd,logfile, ud, self.parent)
+            cmd="Deleting %s" %toDel
+            errors=[]
+            if self.parent:
+                self.parent.emit(SIGNAL("pushCmd(QString, QString)"), ud.owner, cmd)
+            if os.path.isdir(toDel):
+                try:
+                    for root, dirs, files in os.walk(toDel, topdown=False):
+                        for name in files:
+                            os.remove(os.path.join(root, name))
+                        for name in dirs:
+                            os.rmdir(os.path.join(root, name))
+                    os.rmdir(toDel)
+                except Exception, err:
+                    errors.expand((toDel,str(err)))
+            else:
+                try:
+                    os.unlink(toDel)
+                except Exception, err:
+                    errors.expand((toDel,str(err)))
+            msg="[%s] " %_date()
+            if not errors:
+                msg += "Success: "
+            else:
+                msg += "Error:   "
+            msg += cmd
+            for e in errors:
+                msg += " <%s>" %e
+            if self.parent:
+                self.parent.emit(SIGNAL("popCmd(QString, QString)"), ud.owner, msg)
+            self.writeToLog(msg)
